@@ -623,6 +623,7 @@ typedef struct {
     Boolean lowTimeWarning; /* [HGM] low time */
     char *lowTimeWarningColor;
 
+    char *serverFileName;
     char *serverMovesName;
     Boolean suppressLoadMoves;
     int serverPause;
@@ -664,6 +665,7 @@ typedef struct {
     int evalThreshold;  /* [HGM] evalGraph */
     Boolean dropMenu;   /* [HGM] pv        */
     Boolean markers;    /* [HGM] markers   */
+    Boolean autoCopyPV;
     Boolean pieceMenu;
     Boolean sweepSelect;
     Boolean whitePOV;
